#!/usr/bin/env python3
#-*- coding:utf-8 -*-
#==================================================================================
#  Copyright:
#            
#      Copyright (C) 2010 - 2013 Konstas Marmatakis <marmako@gmail.com>
#
#   License:
#  
#      This program is free software; you can redistribute it and/or modify
#      it under the terms of the GNU General Public License version 2 as
#      published by the Free Software Foundation.
#
#      This program is distributed in the hope that it will be useful,
#      but WITHOUT ANY WARRANTY; without even the implied warranty of
#      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#      GNU General Public License for more details.
#
#      You should have received a copy of the GNU General Public License
#      along with this package; if not, write to the Free Software
#      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#================================================================================== 

from tkinter import ttk, Frame, Menu, PhotoImage, Toplevel
from tkinter.messagebox import askyesno, showerror, showinfo
from guinterface.tkuiapodixis import apodixisdata, epixirisisdata, vasi, check_vasi, typoidata, peri, \
    tropo_apodixis, showlicense
from libs.lib import check_sum, create_samples
from libs.fprints import prn_html, expcsv
import webbrowser, os
from tkinter.constants import BOTH, YES, CENTER, RAISED, LEFT, TOP, X, RIGHT,\
    DISABLED


__version__ = open('data/VERSION').read()
__author__ = 'Κώνστας Μαρματάκης'
__author_email__ = 'marmako@gmail.com'

try:
    os.chdir(os.path.join(os.path.expanduser('~'), 'apodixis'))
except:
    pass

class NewMenu(ttk.Frame): # an extended frame
                        
    def __init__(self, parent=None):
        ttk.Frame.__init__(self, parent)
        self.pack(expand=YES, fill=BOTH)
        self.createWidgets()
        self.master.title("Αποδείξεις")    # set window-manager info
        self.master.iconname("Αποδείξεις")           # label when iconified
        self.master.protocol("WM_DELETE_WINDOW", lambda: '') #Δεν κλείνει με x για να γίνουν οι έλεχγοι.
        #Try to set icon.
        try:
            self.master.iconbitmap('@images/apodixi.xpm')
        except:
            img = PhotoImage(file='images/apodixi_logo_new.gif')
            self.master.tk.call('wm', 'iconphoto', self.master._w, img)
        self.master.update_idletasks()
        ws = self.master.winfo_screenwidth()
        hs = self.master.winfo_screenheight()
        self.master.geometry("%dx%d%+d%+d" %  (ws, hs, 0, 0))#(w, h, (ws-w)/2, 5 )
        
        check_vasi(vasi)
        
     
    def createWidgets(self):
        self.makeMenuBar()
        self.makeToolBar()
        imgobj = PhotoImage(file='images/apodixi.gif')
        style= ttk.Style()
        style.configure("yb.TLabel", foreground='#FFFFFF', background= '#c95d13', padding=5, \
                         font=("Arial",24,"bold italic"), relief=RAISED, justify=CENTER) # '#FFF565'
        LIM=ttk.Label(self, image=imgobj, background='#c95d13')
        LIM.config(relief=RAISED)
        LIM.imgobj= imgobj
        LIM.pack(side=LEFT, fill=BOTH)
        L = ttk.Label(self, style="yb.TLabel", anchor=CENTER, text='Καταχώρηση Αποδείξεων\nΈκδοση {0}\nΠρογραμματισμός - Ανάλυση: {1}\nemail: {2}'.format(__version__, __author__, __author_email__))
        
        L.pack(expand=YES,  fill=BOTH)

                
    def makeToolBar(self):
        toolbar = Frame(self, cursor='hand2', relief=RAISED, bg='#c95d13', bd=3)
        toolbar.pack(side=TOP, fill=X)
        styleB= ttk.Style()
        styleB.configure("nb.TButton", foreground='#000000', background='#c95d13', relief=RAISED, border=3, font=("Courier",10,""))
        exodos=ttk.Button(toolbar, text='Έξοδος', style="nb.TButton", command=lambda: self.quit('<Return>') )
        exodos.pack(side=RIGHT)
        exodos.bind('<Return>', self.quit)
        ttk.Button(toolbar, text='Καταχώρηση Αποδείξεων', style="nb.TButton", command=self.apodixis).pack(side=LEFT)
        ttk.Button(toolbar, text='Καταχώρηση Επιχειρήσεων', style="nb.TButton", command=self.epixiris).pack(side=LEFT)
        ttk.Button(toolbar, text='Τύποι Αγοράς', style="nb.TButton", command=self.typoi).pack(side=LEFT)
        ttk.Button(toolbar, text='Επεξεργασία', style="nb.TButton", command=self.epexerg).pack(side=LEFT)
        ttk.Button(toolbar, text='Εκτύπωση', style="nb.TButton", command=self.prnit).pack(side=LEFT)
        
       
        
    def makeMenuBar(self):
        self.menubar = Menu(self.master,bg='#c95d13', fg='#FFFFFF')
        self.master.config(menu=self.menubar)    # master=top-level window
        self.ToolMenu()
        self.fileMenu()

    def fileMenu(self):
        pulldown = Menu(self.menubar,bg='#c95d13', fg='#FFFFFF')
        pulldown.add_command(label='Περί...', command=self.perime)
        pulldown.add_command(label='Copyright', command= self.showlicense)
        self.menubar.add_command(label='Έξοδος', underline=1, command= lambda: self.quit('<Return>'))
        self.menubar.add_cascade(label='Βοήθεια', underline=0, menu=pulldown)
    
    def ToolMenu(self):
        pulldown = Menu(self.menubar,bg='#c95d13', fg='#FFFFFF')
        pulldown.add_command(label= 'Καταχώρηση Αποδείξεων', command =self.apodixis)
        pulldown.add_command(label= 'Καταχώρηση Επιχειρήσεων', command =self.epixiris)
        pulldown.add_command(label= 'Επεξεργασία Αποδείξεων', command =self.epexerg)
        pulldown.add_command(label= 'Τύποι Αγοράς', command =self.typoi)
        pulldown.add_command(label= 'Εκτύπωση', command =self.prnit)
        pulldown.add_command(label='Εξαγωγή σε csv', command=self.export_csv)
        self.menubar.add_cascade(label='Εργαλεία', underline=0, menu=pulldown)
        
    def editMenu(self):
        pulldown = Menu(self.menubar)
        pulldown.add_command(label='Paste',   command=self.notdone)
        pulldown.add_command(label='Spam',    command='')
        pulldown.add_separator()
        pulldown.add_command(label='Delete',  command='')
        pulldown.entryconfig(4, state=DISABLED)
        self.menubar.add_cascade(label='Edit', underline=0, menu=pulldown)
     
    def imageMenu(self):
        photoFiles = ('guido.gif', 'pythonPowered.gif', 'ppython_sm_ad.gif') 
        pulldown = Menu(self.menubar)
        self.photoObjs = []
        for file in photoFiles:
            img = PhotoImage(file='/home/kostas/Gui/gifs/' + file)
            pulldown.add_command(image=img, command=self.notdone)
            self.photoObjs.append(img)   # keep a reference
        self.menubar.add_cascade(label='Image', underline=0, menu=pulldown)
    
    def typoi(self):
        typoidata()
    
    def perime(self):
        """
        About...
        """
        peri()
    
    def showlicense(self):
        """
        License
        """
        showlicense()
    
    def epexerg(self):
        tropo_apodixis()
              
    def apodixis(self):
        """
        Calls the receipt data entry form.
        """
        apodixisdata()
                
    def athrisi(self):
        """
        Sums the receipts.
        """
        return 'Το σύνολο των καταχωρημένων αποδείξεων είναι: {0}.'.format(check_sum(vasi))

    def epixiris(self):
        epixirisisdata()
    
    def notdone(self):  
        showerror('Δεν έχει υλοποιηθεί', 'Η εκτύπωση δεν έχει υλοποιηθεί ακόμη.') 
        
    def prnit(self):
        import tempfile
        from guinterface.newdialog import cdialog
        
        win = Toplevel()
        win.wm_attributes('-topmost', 1)
        win.lift()
        d = cdialog(win, vasi)
        win.lift()
        win.wait_window(d.top)
        
        prn_html(vasi,d.q, d.v)
        htmlfile =  tempfile.gettempdir() + os.sep + 'apodixis.html'
        
        try:
            
            browser = webbrowser.get('firefox')
            browser.open(htmlfile, autoraise=True)
        except:
            webbrowser.open(htmlfile, autoraise=True)
        

    def export_csv(self):
        expcsv(vasi)
        showinfo('Έγινε εξαγωγή', 'Τα δεδομένα εξήχθηκαν στο αρχείο apodixis.csv, που μπορεί ν\' ανοιχθεί με λογιστικό φύλλο της αρεσκείας σας.')
        
    def quit(self, event):
        import tempfile
        htmlfile = tempfile.gettempdir() + '/apodixis.html'
        if askyesno('Επιβεβαίωση Εξόδου', 'Είστε σίγουρος ότι θέλετε να εξέλθετε;'):
            try:
                if os.path.exists(vasi):
                    create_samples(vasi)
            except:
                pass
            try:
                os.unlink(htmlfile)
            except OSError:
                pass
            Frame.quit(self)

if __name__ == '__main__':
    NewMenu().mainloop()
