-- Date: 2014-01-17
-- Table: epixirisis
CREATE TABLE epixirisis (
    afm        VARCHAR NOT NULL
                       UNIQUE ON CONFLICT FAIL,
    doy        VARCHAR NOT NULL,
    eponimia   VARCHAR NOT NULL,
    dieythinsi VARCHAR NOT NULL,
    thlefono   VARCHAR,
    email      VARCHAR DEFAULT (NULL),
    PRIMARY KEY (afm)
);


-- Table: eidos_agoras
CREATE TABLE eidos_agoras (
    eidos_id  INTEGER   NOT NULL
                        PRIMARY KEY,
    perigrafi TEXT(30)  NOT NULL
                        UNIQUE
);


-- Table: apodixis
CREATE TABLE apodixis (
    arithmos_apod VARCHAR     NOT NULL,
    afm           VARCHAR     NOT NULL
                              REFERENCES epixirisis (afm) ON DELETE CASCADE
                                                          ON UPDATE CASCADE,
    doy           VARCHAR     NOT NULL,
    typos_agoras  INTEGER     NOT NULL,
    ddate         DATE        NOT NULL,
    poso          REAL(8, 2)  NOT NULL,
    aa            INTEGER     NOT NULL ON CONFLICT ROLLBACK,
    oik_etos      DATE,
    CONSTRAINT 'protevon' PRIMARY KEY (afm, ddate, arithmos_apod),
    FOREIGN KEY (afm) REFERENCES epixirisis (afm) ON DELETE CASCADE
                                                      ON UPDATE CASCADE
);


-- Index: idx_apodixisoiketos
CREATE INDEX idx_apodixisoiketos ON apodixis (
    oik_etos ASC,
    aa       ASC
);


-- Index: idx_typos_agoras
CREATE INDEX idx_typos_agoras ON apodixis (
    typos_agoras COLLATE BINARY ASC
);


-- Trigger: setoiketos
CREATE TRIGGER setoiketos
       AFTER UPDATE ON apodixis
       FOR EACH ROW
BEGIN
    UPDATE apodixis
       SET oik_etos = strftime('%Y', ddate)
     WHERE aa = NEW.aa;
END;
;


-- Trigger: ins_oiketos
CREATE TRIGGER ins_oiketos
       AFTER INSERT ON apodixis
BEGIN
    UPDATE apodixis
       SET oik_etos = strftime('%Y', ddate)
     WHERE aa = NEW.aa;
END;
;


-- Trigger: fk_apodixis_epixirisis_del1
CREATE TRIGGER fk_apodixis_epixirisis_del1
       BEFORE DELETE ON epixirisis
       WHEN (old.afm IN (
        SELECT afm
          FROM apodixis
         GROUP BY afm
    ) 
) 
BEGIN
    DELETE
      FROM apodixis
     WHERE afm = old.afm;
END;
;


-- Trigger: fk_apodixis_epixirisis_upd1
CREATE TRIGGER fk_apodixis_epixirisis_upd1
       BEFORE UPDATE ON epixirisis
       WHEN (old.afm IN (
        SELECT afm
          FROM apodixis
         GROUP BY afm
    ) 
) 
BEGIN
    UPDATE apodixis
       SET afm = new.afm
     WHERE afm = old.afm;
END;
;


-- Trigger: fk_apodixis_epixirisis_del2
CREATE TRIGGER fk_apodixis_epixirisis_del2
       BEFORE DELETE ON epixirisis
       WHEN (old.afm IN (
        SELECT afm
          FROM apodixis
         GROUP BY afm
    ) 
) 
BEGIN
    DELETE
      FROM apodixis
     WHERE afm = old.afm;
END;
;


-- Trigger: fk_apodixis_epixirisis_upd2
CREATE TRIGGER fk_apodixis_epixirisis_upd2
       BEFORE UPDATE ON epixirisis
       WHEN (old.afm IN (
        SELECT afm
          FROM apodixis
         GROUP BY afm
    ) 
) 
BEGIN
    UPDATE apodixis
       SET afm = new.afm
     WHERE afm = old.afm;
END;
;


-- View: typoi_agoras_in_apodixis
CREATE VIEW typoi_agoras_in_apodixis AS
       SELECT DISTINCT eidos_agoras.perigrafi,
                       eidos_agoras.eidos_id
                  FROM eidos_agoras
                       LEFT OUTER JOIN apodixis
                 WHERE eidos_agoras.eidos_id = apodixis.typos_agoras
                 ORDER BY eidos_agoras.eidos_id;
;

