#==================================================================================
#  Copyright:
#            
#      Copyright (C) 2010 Konstas Marmatakis <marmako@gmail.com>
#
#   License:
#  
#      This program is free software; you can redistribute it and/or modify
#      it under the terms of the GNU General Public License version 2 as
#      published by the Free Software Foundation.
#
#      This program is distributed in the hope that it will be useful,
#      but WITHOUT ANY WARRANTY; without even the implied warranty of
#      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#      GNU General Public License for more details.
#
#      You should have received a copy of the GNU General Public License
#      along with this package; if not, write to the Free Software
#      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#================================================================================== 

'''
Created on Feb 12, 2011
Revised on Feb 15, 2011 7:46:25 PM

@author: Konstas Marmatakis <marmako@gmail.com>
'''
import sqlite3

class pydatabases(object):
    '''A class to make the main tables in the database.
    :Author: Konstas Marmatakis
    :Email: marmako[at]gmail[dot]com
    
    '''
    __author__ = "Konstas Marmatakis"

    def __init__(self, databasename):
        '''
        Constructor
        '''
        self.databasename = databasename
        self.syndesi = sqlite3.connect(databasename)
        self.curr = self.syndesi.cursor()
        
        
    def closeme(self):
        '''
        Commits and closes the database.
        '''
        print('Η βάση "{0}" δημιουργήθηκε'.format(self.databasename))
        self.syndesi.commit()
        self.syndesi.close()
        
    def fill_table(self):
        '''
        Fills the table eidos_agoras
        with data.
        '''
        print("Εισαγωγή εγγραφών στον πίνακα είδος αγοράς....")
        
        vlue = [(1, 'ΤΡΟΦΙΜΑ - ΛΑΧΑΝΙΚΑ'),
        (2, 'ΕΝΔΥΣΗ - ΥΠΟΔΗΣΗ'),
        (3, 'ΚΑΥΣΙΜΑ'),
        (4, 'ΕΣΤΙΑΤΟΡΙΑ - ΤΑΒΕΡΝΕΣ'),
        (5, 'ΠΑΡΚΙΝΚ'),
        (6, 'ΚΟΜΜΩΤΗΡΙΑ'),
        (7, 'ΑΙΣΘΗΤΙΚΟΣ'),
        (8, 'ΑΛΛΕΣ ΥΠΗΡΕΣΙΕΣ'),
        (9, 'ΦΑΡΜΑΚΑ'),
        (10, 'ΖΩΟΤΡΟΦΕΣ'),
        (11, 'EΡΓΑΛΕΙΑ - ΧΡΩΜΑΤΑ - ΣΙΔΗΡΙΚΑ'),
        (12, 'ΒΙΒΛΙΑ - ΧΑΡΤΙΚΑ'),
        (13, 'ΑΝΤΑΛΛΑΚΤΙΚΑ - ΕΠΙΣΚΕΥΕΣ ΟΧΗΜΑΤΩΝ'),
        (14, 'ΚΑΛΛΥΝΤΙΚΑ'),
        (15,'ΗΛΕΚΤΡΙΚΑ ΕΙΔΗ')]
        
        self.curr.executemany("INSERT INTO eidos_agoras (eidos_id, perigrafi) \
        VALUES (?, ?)", vlue)
    
    def create_vasi(self):
        '''
        Creates the database and the tables
        '''
        
        print('Δημιουργία βάσης \"{0}\" και πινάκων... '.format(self.databasename))
       
        self.curr.execute("CREATE TABLE [epixirisis] ([afm] VARCHAR NOT NULL UNIQUE ON CONFLICT FAIL, [doy] VARCHAR NOT\
     NULL, [eponimia] VARCHAR NOT NULL, [dieythinsi] VARCHAR NOT NULL, [thlefono] VARCHAR, PRIMARY KEY ([afm]))")
        
        self.curr.execute("CREATE TABLE [apodixis] ([arithmos_apod] VARCHAR NOT NULL, [afm] VARCHAR NOT NULL\
    REFERENCES [epixirisis](afm) ON DELETE CASCADE ON UPDATE CASCADE, [doy] VARCHAR NOT NULL, \
    [typos_agoras] INTEGER NOT NULL, [ddate] DATE NOT NULL, [poso] REAL(8,2) NOT NULL, [aa] INTEGER NOT NULL UNIQUE ON CONFLICT FAIL, \
    CONSTRAINT \"protevon\" PRIMARY KEY ([afm], [ddate], [arithmos_apod]))")
        
        self.curr.execute("CREATE TABLE [eidos_agoras] ([eidos_id] INTEGER NOT NULL PRIMARY KEY, \
    [perigrafi] TEXT(30) NOT NULL UNIQUE)")
         
        print('Δημιουργία triggers.... ')

        self.curr.execute("CREATE TRIGGER [fk_apodixis_epixirisis_del1] BEFORE DELETE ON [epixirisis] WHEN (old.[afm] IN \
    (SELECT [afm] FROM [apodixis] GROUP BY [afm])) BEGIN DELETE FROM [apodixis] WHERE [afm] = old.[afm];\
    END")
    
        self.curr.execute("CREATE TRIGGER [fk_apodixis_epixirisis_upd1] BEFORE UPDATE ON [epixirisis] WHEN\
    (old.[afm] IN (SELECT [afm] FROM [apodixis] GROUP BY [afm])) BEGIN UPDATE [apodixis]\
    SET [afm] = new.[afm] WHERE [afm] = old.[afm]; END")
    
        self.curr.execute("CREATE TRIGGER [fk_apodixis_epixirisis_del2] BEFORE DELETE ON [epixirisis] WHEN\
    (old.[afm] IN (SELECT [afm] FROM [apodixis] GROUP BY [afm])) BEGIN DELETE FROM [apodixis]\
    WHERE [afm] = old.[afm]; END")
    
        self.curr.execute("CREATE TRIGGER [fk_apodixis_epixirisis_upd2] BEFORE UPDATE ON [epixirisis] WHEN\
     (old.[afm] IN (SELECT [afm] FROM [apodixis] GROUP BY [afm])) BEGIN UPDATE [apodixis] \
     SET [afm] = new.[afm] WHERE [afm] = old.[afm]; END")
        
        self.fill_table()
        
        self.closeme()
        
class restoredatabase(pydatabases):
    def __init__(self, databasename, flname):
        pydatabases.__init__(self, databasename)
        self.flname = flname
        
    def run_from_script(self):
        fh = open(self.flname, 'r')
        keimeno = fh.read()
        self.curr.executescript(keimeno)
        print(keimeno)
        fh.close()
        self.closeme()
        

if __name__ == '__main__':
    from tkinter import Tk, Button
    from tkinter.constants import X
    import guiStreams
    root = Tk()
    root.title('Δοκιμή')
    db = pydatabases('test01.db')
    db1 = restoredatabase('testme01.db', 'data.sql')
    Button(root, text='Δημιουργία Βάσης',
           command=lambda: guiStreams.redirectedGuiFunc(db.create_vasi)).pack(fill=X)
    Button(root, text='Επαναφορά από αρχείο',
           command=lambda: guiStreams.redirectedGuiFunc(db1.run_from_script)).pack(fill=X)
    root.mainloop()